"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _useSyntaxHighlighter = require("../../hooks/useSyntaxHighlighter");
var _jsxRuntime = require("react/jsx-runtime");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/* eslint-disable no-console */

const monospaceFont = _reactNative.Platform.select({
  ios: 'Menlo',
  android: 'monospace',
  default: 'monospace'
});
function transformThemeToStyles(theme) {
  const defaultBackground = theme.colors?.['editor.background'];
  const foreground = theme.colors?.['editor.foreground'];
  console.log('[SyntaxHighlighter] Theme colors:', {
    background: defaultBackground,
    foreground,
    allColors: theme.colors
  });
  const styles = _reactNative.StyleSheet.create({
    scrollView: {
      flex: 1,
      minHeight: 20
    },
    codeContainer: {
      padding: 16,
      minWidth: '100%'
    },
    lineContainer: {
      flexDirection: 'row',
      flexWrap: 'wrap'
    },
    baseToken: {
      fontFamily: monospaceFont
    }
  });
  const colorStyles = new Map();
  return {
    base: styles,
    background: defaultBackground,
    getTokenStyle: token => {
      const key = `${token.color || ''}-${token.fontStyle || ''}`;
      if (!colorStyles.has(key)) {
        const style = {
          color: token.color || foreground,
          fontStyle: token.fontStyle ? 'italic' : 'normal',
          fontWeight: token.fontStyle ? 'bold' : 'normal'
        };
        console.log('[SyntaxHighlighter] Created new token style:', {
          key,
          token,
          style
        });
        colorStyles.set(key, style);
      }
      return colorStyles.get(key);
    }
  };
}
const SyntaxHighlighter = ({
  text,
  language,
  languageId,
  theme,
  fontSize = 14,
  scrollViewProps,
  textStyle,
  containerStyle
}) => {
  const {
    tokens
  } = (0, _useSyntaxHighlighter.useSyntaxHighlighter)({
    text,
    language,
    languageId,
    theme
  });
  const styles = (0, _react.useMemo)(() => transformThemeToStyles(theme), [theme]);
  if (!tokens?.length) {
    return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.ScrollView, {
      horizontal: true,
      ...scrollViewProps,
      style: [styles.base.scrollView, scrollViewProps?.style],
      contentContainerStyle: [styles.base.codeContainer, {
        backgroundColor: styles.background
      }, scrollViewProps?.contentContainerStyle, containerStyle],
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
        style: styles.base.lineContainer,
        children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.Text, {
          style: [styles.base.baseToken, {
            fontSize,
            color: styles.background
          }, textStyle],
          children: text
        })
      })
    });
  }
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.ScrollView, {
    horizontal: true,
    ...scrollViewProps,
    style: [styles.base.scrollView, scrollViewProps?.style],
    contentContainerStyle: [styles.base.codeContainer, {
      backgroundColor: styles.background
    }, scrollViewProps?.contentContainerStyle, containerStyle],
    children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
      children: tokens.map((line, rowIndex) => /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
        style: styles.base.lineContainer,
        children: line.map((token, tokenIndex) => /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.Text, {
          style: [styles.base.baseToken, styles.getTokenStyle(token), {
            fontSize
          }, textStyle],
          children: token.content
        }, `${rowIndex}-${tokenIndex}`))
      }, rowIndex))
    })
  });
};
var _default = exports.default = SyntaxHighlighter;
//# sourceMappingURL=SyntaxHighlighter.js.map