"use strict";

/* eslint-disable no-console */

import React, { useMemo } from 'react';
import { Platform, ScrollView, StyleSheet, Text, View } from 'react-native';
import { useSyntaxHighlighter } from '../../hooks/useSyntaxHighlighter';
import { jsx as _jsx } from "react/jsx-runtime";
const monospaceFont = Platform.select({
  ios: 'Menlo',
  android: 'monospace',
  default: 'monospace'
});
function transformThemeToStyles(theme) {
  const defaultBackground = theme.colors?.['editor.background'];
  const foreground = theme.colors?.['editor.foreground'];
  console.log('[SyntaxHighlighter] Theme colors:', {
    background: defaultBackground,
    foreground,
    allColors: theme.colors
  });
  const styles = StyleSheet.create({
    scrollView: {
      flex: 1,
      minHeight: 20
    },
    codeContainer: {
      padding: 16,
      minWidth: '100%'
    },
    lineContainer: {
      flexDirection: 'row',
      flexWrap: 'wrap'
    },
    baseToken: {
      fontFamily: monospaceFont
    }
  });
  const colorStyles = new Map();
  return {
    base: styles,
    background: defaultBackground,
    getTokenStyle: token => {
      const key = `${token.color || ''}-${token.fontStyle || ''}`;
      if (!colorStyles.has(key)) {
        const style = {
          color: token.color || foreground,
          fontStyle: token.fontStyle ? 'italic' : 'normal',
          fontWeight: token.fontStyle ? 'bold' : 'normal'
        };
        console.log('[SyntaxHighlighter] Created new token style:', {
          key,
          token,
          style
        });
        colorStyles.set(key, style);
      }
      return colorStyles.get(key);
    }
  };
}
const SyntaxHighlighter = ({
  text,
  language,
  languageId,
  theme,
  fontSize = 14,
  scrollViewProps,
  textStyle,
  containerStyle
}) => {
  const {
    tokens
  } = useSyntaxHighlighter({
    text,
    language,
    languageId,
    theme
  });
  const styles = useMemo(() => transformThemeToStyles(theme), [theme]);
  if (!tokens?.length) {
    return /*#__PURE__*/_jsx(ScrollView, {
      horizontal: true,
      ...scrollViewProps,
      style: [styles.base.scrollView, scrollViewProps?.style],
      contentContainerStyle: [styles.base.codeContainer, {
        backgroundColor: styles.background
      }, scrollViewProps?.contentContainerStyle, containerStyle],
      children: /*#__PURE__*/_jsx(View, {
        style: styles.base.lineContainer,
        children: /*#__PURE__*/_jsx(Text, {
          style: [styles.base.baseToken, {
            fontSize,
            color: styles.background
          }, textStyle],
          children: text
        })
      })
    });
  }
  return /*#__PURE__*/_jsx(ScrollView, {
    horizontal: true,
    ...scrollViewProps,
    style: [styles.base.scrollView, scrollViewProps?.style],
    contentContainerStyle: [styles.base.codeContainer, {
      backgroundColor: styles.background
    }, scrollViewProps?.contentContainerStyle, containerStyle],
    children: /*#__PURE__*/_jsx(View, {
      children: tokens.map((line, rowIndex) => /*#__PURE__*/_jsx(View, {
        style: styles.base.lineContainer,
        children: line.map((token, tokenIndex) => /*#__PURE__*/_jsx(Text, {
          style: [styles.base.baseToken, styles.getTokenStyle(token), {
            fontSize
          }, textStyle],
          children: token.content
        }, `${rowIndex}-${tokenIndex}`))
      }, rowIndex))
    })
  });
};
export default SyntaxHighlighter;
//# sourceMappingURL=SyntaxHighlighter.js.map